@@ -169,6 +169,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_events
@@ -187,14 +189,14 @@ class EventbridgeToSns(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        event_rule_props: aws_cdk.aws_events.RuleProps,
+        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
-        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
+        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -211,6 +213,10 @@ class EventbridgeToSns(
         :access: public
         :summary: Constructs a new instance of the EventbridgeToSns class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EventbridgeToSns.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToSnsProps(
             event_rule_props=event_rule_props,
             enable_encryption_with_customer_managed_key=enable_encryption_with_customer_managed_key,
@@ -224,22 +230,22 @@ class EventbridgeToSns(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
         return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="snsTopic")
     def sns_topic(self) -> aws_cdk.aws_sns.Topic:
         return typing.cast(aws_cdk.aws_sns.Topic, jsii.get(self, "snsTopic"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
         return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], jsii.get(self, "encryptionKey"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventBus")
     def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
         return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
@@ -263,14 +269,14 @@ class EventbridgeToSnsProps:
     def __init__(
         self,
         *,
-        event_rule_props: aws_cdk.aws_events.RuleProps,
+        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
-        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
+        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
@@ -283,13 +289,23 @@ class EventbridgeToSnsProps:
         :param topic_props: User provided props to override the default props for the SNS Topic. Default: - Default props are used
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+            event_rule_props = RuleProps(**event_rule_props)
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
+            encryption_key_props = KeyProps(**encryption_key_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
+            event_bus_props = EventBusProps(**event_bus_props)
         if isinstance(topic_props, dict):
-            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
+            topic_props = TopicProps(**topic_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(EventbridgeToSnsProps.__init__)
+            check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
+            check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument encryption_key_props", value=encryption_key_props, expected_type=type_hints["encryption_key_props"])
+            check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
+            check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
+            check_type(argname="argument existing_topic_obj", value=existing_topic_obj, expected_type=type_hints["existing_topic_obj"])
+            check_type(argname="argument topic_props", value=topic_props, expected_type=type_hints["topic_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
         }
